summaryrefslogtreecommitdiff
path: root/ucb/source/ucp/ftp/ftploaderthread.cxx
diff options
context:
space:
mode:
authorAndreas Bille <abi@openoffice.org>2002-08-28 06:23:17 +0000
committerAndreas Bille <abi@openoffice.org>2002-08-28 06:23:17 +0000
commit596dca1ba20842c3820d4c6fd91dcd596614232a (patch)
treeb401044597f03ed3a28de2a5976b1a4086affb04 /ucb/source/ucp/ftp/ftploaderthread.cxx
parent66588fcf6a5a9fd90fa192eaaee2139426f3b894 (diff)
Simply saving
Diffstat (limited to 'ucb/source/ucp/ftp/ftploaderthread.cxx')
-rw-r--r--ucb/source/ucp/ftp/ftploaderthread.cxx12
1 files changed, 6 insertions, 6 deletions
diff --git a/ucb/source/ucp/ftp/ftploaderthread.cxx b/ucb/source/ucp/ftp/ftploaderthread.cxx
index 764ed1233875..90d023dc9533 100644
--- a/ucb/source/ucp/ftp/ftploaderthread.cxx
+++ b/ucb/source/ucp/ftp/ftploaderthread.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: ftploaderthread.cxx,v $
*
- * $Revision: 1.3 $
+ * $Revision: 1.4 $
*
- * last change: $Author: abi $ $Date: 2002-06-24 15:17:55 $
+ * last change: $Author: abi $ $Date: 2002-08-28 07:23:13 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -99,24 +99,24 @@ extern "C" {
/********************************************************************************/
/* */
/* Member part of FtpLoaderThread */
/* */
/********************************************************************************/
-FtpLoaderThread::FtpLoaderThread()
+FTPLoaderThread::FTPLoaderThread()
: m_threadKey(osl_createThreadKey(delete_CURL)) {
}
-FtpLoaderThread::~FtpLoaderThread() {
+FTPLoaderThread::~FTPLoaderThread() {
osl_destroyThreadKey(m_threadKey);
}
-CURL* FtpLoaderThread::handle() {
+CURL* FTPLoaderThread::handle() {
CURL* ret;
if(!(ret = osl_getThreadKeyData(m_threadKey))) {
ret = curl_easy_init();
@@ -99,24 +99,24 @@ extern "C" {
/********************************************************************************/
/* */
-/* Member part of FtpLoaderThread */
+/* Member part of FTPLoaderThread */
/* */
/********************************************************************************/